@@ -1,7 +1,7 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2010 Michael Howitz
 # See also LICENSE.txt
-# $Id: tests.py 795 2010-01-19 19:51:13Z icemac $
+# $Id: tests.py 875 2010-03-20 10:25:07Z icemac $
 
 import icemac.addressbook.testing
 import zope.testing.renormalizing
@@ -19,6 +19,7 @@ def test_suite():
         "browser/export/userfields.txt",
         "browser/keyword/keyword.txt",
         "browser/masterdata/masterdata.txt",
+        "browser/person/clone.txt",
         "browser/person/file.txt",
         "browser/person/person.txt",
         "browser/person/translation.txt",
@@ -28,7 +29,7 @@ def test_suite():
         )
     suite.addTest(
         icemac.addressbook.testing.FunctionalDocFileSuite(
-            # Tests which do not need the default <DATETIME> normalizer:
+            # Tests which must not run with the default <DATETIME> normalizer:
             "browser/metadata.txt",
             checker=zope.testing.renormalizing.RENormalizing([])
             ))
