@@ -9,9 +9,7 @@ import zope.container.contained
 import zope.dottedname.resolve
 import zope.interface
 import zope.schema
-
-
-marker = object()
+import zope.interface.interfaces
 
 
 class Entities(object):
@@ -19,44 +17,46 @@ class Entities(object):
 
     zope.interface.implements(icemac.addressbook.interfaces.IEntities)
 
-    def getEntity(self, something):
-        if isinstance(something, str):
-            return self._get_entity_by_name(something)
-        if issubclass(something, zope.interface.Interface):
-            return self._get_entity_by_interface(something)
-        raise TypeError("Don't know how to handle %r." % something)
-
-    def getTitle(self, something):
-        return self.getEntity(something).title
-
     def getAllEntities(self):
         return zope.component.getAllUtilitiesRegisteredFor(
             icemac.addressbook.interfaces.IEntity)
 
-    def _get_entity_by_name(self, name, default=marker):
-        entity = default
-        for candidate in self.getAllEntities():
-            if candidate.name == name:
-                entity = candidate
-                break
-        if entity is marker:
-            raise ValueError("Unknown name: %r" % name)
-        return entity
-
-    def _get_entity_by_interface(self, interface):
-        for entity in self.getAllEntities():
-            if entity.interface == interface:
-                return entity
-        # no utility found, create entity on the fly, so all even
-        # not preconfigured entities can be used the same way as the
-        # preconfigured ones.
-        return Entity(None, interface, None)
 
 
 class PersistentEntities(Entities, zope.container.btree.BTreeContainer):
     "Predefined and user defined entities in the address book."
 
 
+@zope.interface.implementer(icemac.addressbook.interfaces.IEntity)
+@zope.component.adapter(str)
+def entity_by_name(name):
+    "Adapt Entity.name (not Entity.class_name!) to entity."
+    result = None
+    entities = zope.component.getUtility(
+        icemac.addressbook.interfaces.IEntities).getAllEntities()
+    for candidate in entities:
+        if candidate.name == name:
+            result = candidate
+            break
+    if result is None:
+        raise ValueError("Unknown name: %r" % name)
+    return result
+
+
+@zope.interface.implementer(icemac.addressbook.interfaces.IEntity)
+@zope.component.adapter(zope.interface.interfaces.IInterface)
+def entity_by_interface(interface):
+    entities = zope.component.getUtility(
+        icemac.addressbook.interfaces.IEntities).getAllEntities()
+    for entity in entities:
+        if entity.interface == interface:
+            return entity
+    # no utility found, create entity on the fly, so all even
+    # not preconfigured entities can be used the same way as the
+    # preconfigured ones.
+    return Entity(None, interface, None)
+
+
 class ChoiceFieldValuesSource(zc.sourcefactory.basic.BasicSourceFactory):
     "Source containing the values of a choice field."
 
@@ -116,6 +116,9 @@ class Entity(object):
 
     @property
     def name(self):
+        if not self.class_name:
+            raise ValueError(
+                "Entity has no `class_name` set, so `name` cannot be computed.")
         parts = self.class_name.replace('_', '.').split('.')
         return ''.join(x.capitalize() for x in parts)
 
@@ -148,6 +151,15 @@ class Entity(object):
         raise ValueError("class_name is not set.")
 
 
+def create_entity(title, interface, class_):
+    "Factory to create an entity and to the ZCA set up."
+    class_name = '%s.%s' % (class_.__module__, class_.__name__)
+    entity = Entity(title, interface, class_name)
+    zope.interface.classImplements(
+        class_, icemac.addressbook.interfaces.IMayHaveUserFields)
+    return entity
+
+
 class Field(persistent.Persistent, zope.container.contained.Contained):
     """User defined field."""
 
@@ -199,17 +211,12 @@ class FieldStorage(persistent.Persistent):
         # We have no default values on the class nor we might know them.
         if not attrib.startswith('__'):
             return self.__dict__.get(attrib, None)
+        # Cloning a person tries to access __reduce_ex__ and
+        # __reduce__ which are not in __dict__. It is expeced that
+        # they are either methods or not existing, so None is no valid
+        # return value.
         raise AttributeError(attrib)
 
 
 field_storage = zope.annotation.factory(
     FieldStorage, key='icemac.userfield.storage')
-
-
-def create_entity(title, interface, class_):
-    "Factory to create an entity and to the ZCA set up."
-    class_name = '%s.%s' % (class_.__module__, class_.__name__)
-    entity = Entity(title, interface, class_name)
-    zope.interface.classImplements(
-        class_, icemac.addressbook.interfaces.IMayHaveUserFields)
-    return entity
