@@ -1,7 +1,7 @@
 # -*- coding: latin-1 -*-
-# Copyright (c) 2008-2009 Michael Howitz
+# Copyright (c) 2008-2010 Michael Howitz
 # See also LICENSE.txt
-# $Id: interfaces.py 235 2009-01-02 12:47:38Z mac $
+# $Id: interfaces.py 783 2010-01-09 14:28:06Z icemac $
 
 import zope.interface
 
@@ -15,9 +15,12 @@ class IExporter(zope.interface.Interface):
         u'Extension (without the leading dot!) to be set on export file name.')
     mime_type = zope.interface.Attribute(u'Mime-type of the export file.')
 
-    def export(*persons):
-        """Export the `persons` to a file.
+    def export():
+        """Export to a file.
 
         Returns a file or file-like-object.
 
         """
+
+    def __eq__(other):
+        """Checks whether two instances have the same class."""
